Learn R Programming

swirl (version 2.2.6)

func_of_newvar_equals: Tests the result of a computation such as mean(newVar) applied to a specific variable created in a previous question and saved as e$newVar.

Description

Tests the result of a computation such as mean(newVar) applied to a specific variable created in a previous question and saved as e$newVar.

Usage

func_of_newvar_equals(correct_expression)

Arguments

correct_expression
expression expected to be applied

Value

  • TRUE or FALSE

Examples

Run this code
# Test if user has taken the mean of a variable created
# in an earlier question.
#
func_of_newvar_equals('mean(newVar)')

Run the code above in your browser using DataLab