Learn R Programming

swirl (version 2.2.0)

install_from_swirl: Install a course from the official course repository

Description

We are currently maintaining a central repository of contributed swirl courses at https://github.com/swirldev/swirl_courses. This function provides the easiest method of installing a course form the repository.

Usage

install_from_swirl(course_name)

Arguments

course_name
The name of the course you wish to install.

Examples

Run this code
install_from_swirl("R_Programming") # Directory name

### OR ###

install_from_swirl("R Programming") # Course name

Run the code above in your browser using DataLab