func_of_newvar_equals: Tests the result of a computation such as mean(newVar) applied
to a specific variable created in a previous question and
saved as e$newVar.
Description
Tests the result of a computation such as mean(newVar) applied
to a specific variable created in a previous question and
saved as e$newVar.