install_from_swirl: Install a course from the official course repository
Description
We are currently maintaining a central repository of contributed
swirl courses at https://github.com/swirldev/swirl_courses.
This function provides the easiest method of installing a course
form the repository.